{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Annotate a vg graph with bed",
            "doc": "Includes all genome paths",
            "hints": [
                {
                    "dockerPull": "quay.io/vgteam/vg:dev-v1.12.1-51-g28ef4e32-t258-run",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "1.12.1"
                            ],
                            "specs": [
                                "https://doi.org/10.1038/nbt.4227"
                            ],
                            "package": "vg"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3003",
                    "id": "#annotate_a_vg_with_a_bed.cwl/bed"
                },
                {
                    "type": "File",
                    "id": "#annotate_a_vg_with_a_bed.cwl/xg"
                }
            ],
            "baseCommand": [
                "vg",
                "annotate"
            ],
            "arguments": [
                {
                    "prefix": "--xg-name",
                    "valueFrom": "$(inputs.xg.path)"
                },
                {
                    "prefix": "--bed-name",
                    "valueFrom": "$(inputs.bed.path)"
                },
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "stdout": "$(inputs.xg.nameroot).gam",
            "id": "#annotate_a_vg_with_a_bed.cwl",
            "outputs": [
                {
                    "type": "File",
                    "id": "#annotate_a_vg_with_a_bed.cwl/gam",
                    "outputBinding": {
                        "glob": "$(inputs.xg.nameroot).gam"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "doc": "Join the proteomes and genome lists so that we have only Ensembl Bacteria genomes that have non redundant UniProtKB proteome. Which at the time of writing gives 200 genomes.",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": "tail",
            "inputs": [
                {
                    "type": "File",
                    "doc": "A tab seperated file with UniProt proteome and assembly identifiers from\nUniProt that have an as ancestor a the input NCBI ncbiTaxid\n",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "id": "#convertAssemblyIdsFromUniProtIntoRegex.cwl/assembly_identifiers"
                }
            ],
            "arguments": [
                "-n",
                "+2",
                "$(inputs.assembly_identifiers.path)",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "cut",
                "-f",
                "2",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "tr",
                "\\n",
                {
                    "valueFrom": "\"|\"",
                    "shellQuote": true
                }
            ],
            "stdout": "regex.re",
            "outputs": [
                {
                    "type": "string",
                    "outputBinding": {
                        "glob": "regex.re",
                        "loadContents": true,
                        "outputEval": "$(self[0].contents.substring(0,self[0].contents.length-1))"
                    },
                    "id": "#convertAssemblyIdsFromUniProtIntoRegex.cwl/assembly_identifiers_as_regex"
                }
            ],
            "id": "#convertAssemblyIdsFromUniProtIntoRegex.cwl"
        },
        {
            "class": "Workflow",
            "inputs": [
                {
                    "type": "string",
                    "id": "#main/my_baseuri"
                },
                {
                    "type": "string",
                    "id": "#main/my_ncbiTaxid"
                }
            ],
            "steps": [
                {
                    "run": "#annotate_a_vg_with_a_bed.cwl",
                    "in": [
                        {
                            "source": "#main/get_ensembl_bed/concatenated_ensembl_bed",
                            "id": "#main/annotate/bed"
                        },
                        {
                            "source": "#main/xg_index_the_vg/genome_xg",
                            "id": "#main/annotate/xg"
                        }
                    ],
                    "out": [
                        "#main/annotate/gam"
                    ],
                    "id": "#main/annotate"
                },
                {
                    "run": "#convertAssemblyIdsFromUniProtIntoRegex.cwl",
                    "in": [
                        {
                            "source": "#main/fetch_assembly_ids/assembly_identifiers",
                            "id": "#main/convertAssemblyIdsFromUniProtIntoRegex/assembly_identifiers"
                        }
                    ],
                    "out": [
                        "#main/convertAssemblyIdsFromUniProtIntoRegex/assembly_identifiers_as_regex"
                    ],
                    "id": "#main/convertAssemblyIdsFromUniProtIntoRegex"
                },
                {
                    "run": "#retrieve_assembly_identifiers_for_proteomes_from_uniprot.cwl",
                    "in": [
                        {
                            "source": "#main/my_ncbiTaxid",
                            "id": "#main/fetch_assembly_ids/ncbiTaxid"
                        }
                    ],
                    "out": [
                        "#main/fetch_assembly_ids/assembly_identifiers"
                    ],
                    "id": "#main/fetch_assembly_ids"
                },
                {
                    "run": "#retrieve_metadata_from_ensembl_by_ncbi_taxid.cwl",
                    "in": [
                        {
                            "source": "#main/my_ncbiTaxid",
                            "id": "#main/fetch_ensembl_metadata/ncbiTaxid"
                        }
                    ],
                    "out": [
                        "#main/fetch_ensembl_metadata/ensemblgenomes_metadata"
                    ],
                    "id": "#main/fetch_ensembl_metadata"
                },
                {
                    "run": "#retrieve_turtle_from_ensembl.cwl",
                    "in": [
                        {
                            "source": "#main/filter_ensembl_metadata/filtered_ensemblgenomes_metadata",
                            "id": "#main/fetch_ensembl_ttl/filtered_ensemblgenomes_metadata"
                        }
                    ],
                    "out": [
                        "#main/fetch_ensembl_ttl/concatenated_ensembl_turtle"
                    ],
                    "id": "#main/fetch_ensembl_ttl"
                },
                {
                    "run": "#retrieve_genomic_fasta_from_ensembl_ftp.cwl",
                    "in": [
                        {
                            "source": "#main/filter_ensembl_metadata/filtered_ensemblgenomes_metadata",
                            "id": "#main/fetch_fasta/filtered_ensemblgenomes_metadata"
                        }
                    ],
                    "out": [
                        "#main/fetch_fasta/concatenated_ensembl_fasta"
                    ],
                    "id": "#main/fetch_fasta"
                },
                {
                    "run": "#retrieve_rdf_from_uniprot.cwl",
                    "in": [
                        {
                            "source": "#main/filter_ensembl_metadata/filtered_ensemblgenomes_metadata",
                            "id": "#main/fetch_uniprot/filtered_ensemblgenomes_metadata"
                        }
                    ],
                    "out": [
                        "#main/fetch_uniprot/concatenated_uniprot_turtle"
                    ],
                    "id": "#main/fetch_uniprot"
                },
                {
                    "run": "#filter_ensembl_records_by_assembly_id.cwl",
                    "in": [
                        {
                            "source": "#main/convertAssemblyIdsFromUniProtIntoRegex/assembly_identifiers_as_regex",
                            "id": "#main/filter_ensembl_metadata/assembly_identifiers_as_regex"
                        },
                        {
                            "source": "#main/fetch_ensembl_metadata/ensemblgenomes_metadata",
                            "id": "#main/filter_ensembl_metadata/ensemblgenomes_metadata"
                        },
                        {
                            "source": "#main/my_ncbiTaxid",
                            "id": "#main/filter_ensembl_metadata/ncbiTaxid"
                        }
                    ],
                    "out": [
                        "#main/filter_ensembl_metadata/filtered_ensemblgenomes_metadata"
                    ],
                    "id": "#main/filter_ensembl_metadata"
                },
                {
                    "run": "#fix_iris_in_turtle_from_ensembl.cwl",
                    "in": [
                        {
                            "source": "#main/fetch_ensembl_ttl/concatenated_ensembl_turtle",
                            "id": "#main/fix_ensembl_turtle/ensembl_turtle"
                        }
                    ],
                    "out": [
                        "#main/fix_ensembl_turtle/fixed_ensembl_turtle"
                    ],
                    "id": "#main/fix_ensembl_turtle"
                },
                {
                    "run": "#retrieve_bed_files_from_ensembl.cwl",
                    "in": [
                        {
                            "source": "#main/filter_ensembl_metadata/filtered_ensemblgenomes_metadata",
                            "id": "#main/get_ensembl_bed/filtered_ensemblgenomes_metadata"
                        }
                    ],
                    "out": [
                        "#main/get_ensembl_bed/concatenated_ensembl_bed"
                    ],
                    "id": "#main/get_ensembl_bed"
                },
                {
                    "run": "#vg_mod_with_a_gam.cwl",
                    "in": [
                        {
                            "source": "#main/annotate/gam",
                            "id": "#main/mod/gam"
                        },
                        {
                            "source": "#main/msga_the_fasta/genome_graph",
                            "id": "#main/mod/vg"
                        }
                    ],
                    "out": [
                        "#main/mod/modded_vg"
                    ],
                    "id": "#main/mod"
                },
                {
                    "run": "#fasta_vg_msga_into_graph.cwl",
                    "in": [
                        {
                            "source": "#main/fetch_fasta/concatenated_ensembl_fasta",
                            "id": "#main/msga_the_fasta/fastas"
                        }
                    ],
                    "out": [
                        "#main/msga_the_fasta/genome_graph"
                    ],
                    "id": "#main/msga_the_fasta"
                },
                {
                    "run": "#vg_to_turtle.cwl",
                    "in": [
                        {
                            "source": "#main/my_baseuri",
                            "id": "#main/vg_to_turtle/baseIRI"
                        },
                        {
                            "source": "#main/mod/modded_vg",
                            "id": "#main/vg_to_turtle/vg"
                        }
                    ],
                    "out": [
                        "#main/vg_to_turtle/genome_turtle"
                    ],
                    "id": "#main/vg_to_turtle"
                },
                {
                    "run": "#xg_index_vg.cwl",
                    "in": [
                        {
                            "source": "#main/msga_the_fasta/genome_graph",
                            "id": "#main/xg_index_the_vg/vg"
                        }
                    ],
                    "out": [
                        "#main/xg_index_the_vg/genome_xg"
                    ],
                    "id": "#main/xg_index_the_vg"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/fix_ensembl_turtle/fixed_ensembl_turtle",
                    "outputBinding": {
                        "glob": "ensembl-$(inputs.my_ncbiTaxid).ttl.gz"
                    },
                    "id": "#main/ensembl"
                },
                {
                    "type": "File",
                    "outputSource": "#main/fetch_uniprot/concatenated_uniprot_turtle",
                    "outputBinding": {
                        "glob": "uniprot-from-proteomes-in-$(inputs.my_ncbiTaxid).ttl.gz"
                    },
                    "id": "#main/uniprot"
                },
                {
                    "type": "File",
                    "outputSource": "#main/vg_to_turtle/genome_turtle",
                    "outputBinding": {
                        "glob": "vg-from-ensembl-genes-and-genomes-$(inputs.my_ncbiTaxid).ttl.gz"
                    },
                    "id": "#main/vg"
                }
            ],
            "id": "#main"
        },
        {
            "class": "CommandLineTool",
            "label": "Construct a genome graph",
            "doc": "Includes all genome paths",
            "hints": [
                {
                    "dockerPull": "quay.io/vgteam/vg:dev-v1.12.1-51-g28ef4e32-t258-run",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "1.12.1"
                            ],
                            "specs": [
                                "https://doi.org/10.1038/nbt.4227"
                            ],
                            "package": "vg"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#fasta_vg_msga_into_graph.cwl/fastas"
                }
            ],
            "baseCommand": [
                "vg",
                "msga"
            ],
            "arguments": [
                "--circularize",
                {
                    "prefix": "--from",
                    "valueFrom": "$(inputs.fastas)"
                },
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                }
            ],
            "stdout": "$(inputs.fastas.nameroot).vg",
            "outputs": [
                {
                    "type": "File",
                    "id": "#fasta_vg_msga_into_graph.cwl/genome_graph",
                    "outputBinding": {
                        "glob": "$(inputs.fastas.nameroot).vg"
                    }
                }
            ],
            "id": "#fasta_vg_msga_into_graph.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Generate a four column csv file with the name in the first column,the assembly id in the second and the database subsection name in the third and the escaped species name as used in URLs in the last.",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "hints": [
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "jq"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "jq",
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_ensembl_records_by_assembly_id.cwl/assembly_identifiers_as_regex"
                },
                {
                    "type": "File",
                    "id": "#filter_ensembl_records_by_assembly_id.cwl/ensemblgenomes_metadata"
                },
                {
                    "type": "string",
                    "id": "#filter_ensembl_records_by_assembly_id.cwl/ncbiTaxid"
                }
            ],
            "arguments": [
                "-c",
                "[.[]|select(.assembly_id|test(\"$(inputs.assembly_identifiers_as_regex)\"))|.]",
                "$(inputs.ensemblgenomes_metadata.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.ncbiTaxid)_filtered_ensembl_metadata.json"
                    },
                    "id": "#filter_ensembl_records_by_assembly_id.cwl/filtered_ensemblgenomes_metadata"
                }
            ],
            "stdout": "$(inputs.ncbiTaxid)_filtered_ensembl_metadata.json",
            "id": "#filter_ensembl_records_by_assembly_id.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Fix IRIs in ensembl RDF because ensembl cant be bothered",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "sed"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "zcat",
            "inputs": [
                {
                    "type": "File",
                    "id": "#fix_iris_in_turtle_from_ensembl.cwl/ensembl_turtle"
                }
            ],
            "arguments": [
                "$(inputs.ensembl_turtle.path)",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "sed -e 's/identifiers.org\\/uniprot/purl.uniprot.org\\/uniprot/g'",
                {
                    "valueFrom": "|",
                    "shellQuote": false
                },
                "gzip"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "ensembl.ttl.gz"
                    },
                    "id": "#fix_iris_in_turtle_from_ensembl.cwl/fixed_ensembl_turtle"
                }
            ],
            "stdout": "ensembl.ttl.gz",
            "id": "#fix_iris_in_turtle_from_ensembl.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve assembly id\u2019s for E.coli proteomes that are non redundant in UniProtKB",
            "label": "get assembly ids for proteome per taxid from UniProtKB",
            "baseCommand": "curl",
            "inputs": [
                {
                    "type": "string",
                    "id": "#retrieve_assembly_identifiers_for_proteomes_from_uniprot.cwl/ncbiTaxid"
                }
            ],
            "arguments": [
                "https://www.uniprot.org/proteomes/?query=taxonomy%3A$(inputs.ncbiTaxid)+redundant%3Ano&format=tab&columns=id,assembly"
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "A tab seperated file with NCBI Taxon and assembly identifiers from UniProt that have an as ancestor a the input NCBI ncbiTaxid",
                    "format": "https://www.iana.org/assignments/media-types/text/tab-separated-values",
                    "outputBinding": {
                        "glob": "ncbiTaxonomyIndentifiersWithAssemblyFromUniProtThatHaveAsAncestor$(inputs.ncbiTaxid).tsv"
                    },
                    "id": "#retrieve_assembly_identifiers_for_proteomes_from_uniprot.cwl/assembly_identifiers"
                }
            ],
            "stdout": "ncbiTaxonomyIndentifiersWithAssemblyFromUniProtThatHaveAsAncestor$(inputs.ncbiTaxid).tsv",
            "id": "#retrieve_assembly_identifiers_for_proteomes_from_uniprot.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve chromosomal fastas  id\u2019s for the assemblys that are present in UniProtKB",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python3"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "python3",
            "inputs": [
                {
                    "type": "File",
                    "id": "#retrieve_bed_files_from_ensembl.cwl/filtered_ensemblgenomes_metadata"
                }
            ],
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nimport urllib.request\nwith open('$(inputs.filtered_ensemblgenomes_metadata.path)', 'r') as f:\n    genomes = json.load(f)\n    with open('/dev/stdout', 'wb') as fasta:\n        for genome in genomes:\n            stepSize=50000\n            start=0;\n            for end in range(stepSize, int(genome['base_count']), stepSize):\n                bed=\"https://rest.ensemblgenomes.org/overlap/region/\"+genome['species']+\"/Chromosome:\"+str(start)+\":\"+str(end)+\"?feature=gene;content-type=text/x-bed\"\n                start = start+stepSize\n                with urllib.request.urlopen(bed) as response:\n                    data=response.read()\n                    assembly_name=genome['assembly_name'].encode('utf-8')\n                    base_count=genome['base_count'].encode('utf-8')\n                    data=data.replace(b'chrChromosome',b''+assembly_name+b':'+assembly_name+b':Chromosome:1:'+base_count+b':1');\n                    fasta.write(data)\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_3003",
                    "type": "File",
                    "outputBinding": {
                        "glob": "ensembl.bed"
                    },
                    "id": "#retrieve_bed_files_from_ensembl.cwl/concatenated_ensembl_bed"
                }
            ],
            "stdout": "ensembl.bed",
            "id": "#retrieve_bed_files_from_ensembl.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve chromosomal fastas  id\u2019s for the assemblys that are present in UniProtKB",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python3"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "python3",
            "inputs": [
                {
                    "type": "File",
                    "id": "#retrieve_genomic_fasta_from_ensembl_ftp.cwl/filtered_ensemblgenomes_metadata"
                }
            ],
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nimport urllib.request\nimport gzip\nwith open('$(inputs.filtered_ensemblgenomes_metadata.path)', 'r') as f:\n  genomes = json.load(f)\n  with open('/dev/stdout', 'wb') as fasta:\n    for genome in genomes:\n      collection=genome['dbname'].lower().split('_core')[0]\n      loc=\"/pub/current/bacteria/fasta/\"+collection+\"/\"+genome['species']+\"/dna/\"\n      genomeFasta=genome['species'].capitalize()+'.'+genome['assembly_name']+'.dna.chromosome.Chromosome.fa.gz'\n      with urllib.request.urlopen('ftp://ftp.ensemblgenomes.org'+loc+genomeFasta) as response:\n        data=gzip.decompress(response.read())\n        data=data.replace(b'>Chromosome dna:chromosome chromosome',b'>'+genome['assembly_name'].encode('utf-8'));\n        fasta.write(data)\n"
                }
            ],
            "outputs": [
                {
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "ensembl.fasta"
                    },
                    "id": "#retrieve_genomic_fasta_from_ensembl_ftp.cwl/concatenated_ensembl_fasta"
                }
            ],
            "stdout": "ensembl.fasta",
            "id": "#retrieve_genomic_fasta_from_ensembl_ftp.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve metadata for Ensembl Genome data from taxid",
            "baseCommand": "curl",
            "inputs": [
                {
                    "type": "string",
                    "id": "#retrieve_metadata_from_ensembl_by_ncbi_taxid.cwl/ncbiTaxid"
                }
            ],
            "arguments": [
                "-f",
                "https://rest.ensemblgenomes.org/info/genomes/taxonomy/$(inputs.ncbiTaxid)?content-type=application/json"
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "A json file from the ensemblgenomes website that",
                    "format": "https://www.iana.org/assignments/media-types/text/application/json",
                    "outputBinding": {
                        "glob": "ensemblgenomesMetadataForTaxid$(inputs.ncbiTaxid).json"
                    },
                    "id": "#retrieve_metadata_from_ensembl_by_ncbi_taxid.cwl/ensemblgenomes_metadata"
                }
            ],
            "stdout": "ensemblgenomesMetadataForTaxid$(inputs.ncbiTaxid).json",
            "id": "#retrieve_metadata_from_ensembl_by_ncbi_taxid.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve rdf from uniprot the proteins for the proteomes",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python3"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "python3",
            "inputs": [
                {
                    "type": "File",
                    "id": "#retrieve_rdf_from_uniprot.cwl/filtered_ensemblgenomes_metadata"
                }
            ],
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nimport urllib.request\nwith open('$(inputs.filtered_ensemblgenomes_metadata.path)', 'r') as f:\n  genomes = json.load(f)\n  with open('/dev/stdout', 'wb') as turtle:\n    for genome in genomes:\n      loc=\"https://www.uniprot.org/uniprot/?format=ttl&compressed=yes&query=proteome:(assembly_id:\"+genome['assembly_id']+\")\"\n      with urllib.request.urlopen(loc) as response:\n        turtle.write(response.read())\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "uniprot.ttl.gz"
                    },
                    "id": "#retrieve_rdf_from_uniprot.cwl/concatenated_uniprot_turtle"
                }
            ],
            "stdout": "uniprot.ttl.gz",
            "id": "#retrieve_rdf_from_uniprot.cwl"
        },
        {
            "class": "CommandLineTool",
            "doc": "Retrieve ttl from ensemblgenomes the assemblys that are present in UniProtKB",
            "hints": [
                {
                    "packages": [
                        {
                            "package": "python3"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "baseCommand": "python3",
            "inputs": [
                {
                    "type": "File",
                    "id": "#retrieve_turtle_from_ensembl.cwl/filtered_ensemblgenomes_metadata"
                }
            ],
            "arguments": [
                {
                    "prefix": "-c",
                    "valueFrom": "import json\nimport urllib.request\nwith open('$(inputs.filtered_ensemblgenomes_metadata.path)', 'r') as f:\n  genomes = json.load(f)\n  with open('/dev/stdout', 'wb') as fasta:\n    for genome in genomes:\n      collection=genome['dbname'].lower().split('_core')[0]\n      loc=\"/pub/current/bacteria/rdf/\"+collection+\"/\"+genome['species']+'/'\n      genomeTtl=genome['species']+'.ttl.gz'\n      with urllib.request.urlopen('ftp://ftp.ensemblgenomes.org'+loc+genomeTtl) as response:\n        fasta.write(response.read())\n      genomeXref=genome['species']+'.ttl.gz'\n      with urllib.request.urlopen('ftp://ftp.ensemblgenomes.org'+loc+genomeXref) as response:\n        fasta.write(response.read())\n"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "ensembl.ttl.gz"
                    },
                    "id": "#retrieve_turtle_from_ensembl.cwl/concatenated_ensembl_turtle"
                }
            ],
            "stdout": "ensembl.ttl.gz",
            "id": "#retrieve_turtle_from_ensembl.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Augment/mod a vg with a gam",
            "doc": "Adds the paths contained in the gam into the vg",
            "hints": [
                {
                    "dockerPull": "quay.io/vgteam/vg:dev-v1.12.1-51-g28ef4e32-t258-run",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "1.12.1"
                            ],
                            "specs": [
                                "https://doi.org/10.1038/nbt.4227"
                            ],
                            "package": "vg"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#vg_mod_with_a_gam.cwl/gam"
                },
                {
                    "type": "File",
                    "id": "#vg_mod_with_a_gam.cwl/vg"
                }
            ],
            "baseCommand": [
                "vg",
                "augment"
            ],
            "arguments": [
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                },
                "$(inputs.vg.path)",
                "$(inputs.gam.path)"
            ],
            "stdout": "$(inputs.vg.nameroot)_modded.vg",
            "outputs": [
                {
                    "type": "File",
                    "id": "#vg_mod_with_a_gam.cwl/modded_vg",
                    "outputBinding": {
                        "glob": "$(inputs.vg.nameroot)_modded.vg"
                    }
                }
            ],
            "id": "#vg_mod_with_a_gam.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Export a vg to turtle rdf",
            "doc": "This allows it being loaded into a triples store",
            "hints": [
                {
                    "dockerPull": "quay.io/vgteam/vg:dev-v1.12.1-51-g28ef4e32-t258-run",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "1.12.1"
                            ],
                            "specs": [
                                "https://doi.org/10.1038/nbt.4227"
                            ],
                            "package": "vg"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#vg_to_turtle.cwl/baseIRI"
                },
                {
                    "type": "File",
                    "id": "#vg_to_turtle.cwl/vg"
                }
            ],
            "baseCommand": [
                "vg",
                "view"
            ],
            "arguments": [
                {
                    "prefix": "-r",
                    "valueFrom": "$(inputs.baseIRI)"
                },
                {
                    "prefix": "--vg-in",
                    "valueFrom": "$(inputs.vg.path)"
                },
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                },
                "--turtle"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "vg-$(inputs.vg.basename).ttl.gz"
                    },
                    "id": "#vg_to_turtle.cwl/genome_turtle"
                }
            ],
            "stdout": "vg-$(inputs.vg.basename).ttl.gz",
            "id": "#vg_to_turtle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Index a vg with xg",
            "doc": "The XG index allows faster access to vg",
            "hints": [
                {
                    "dockerPull": "quay.io/vgteam/vg:dev-v1.12.1-51-g28ef4e32-t258-run",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "version": [
                                "1.12.1"
                            ],
                            "specs": [
                                "https://doi.org/10.1038/nbt.4227"
                            ],
                            "package": "vg"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#xg_index_vg.cwl/vg"
                }
            ],
            "baseCommand": [
                "vg",
                "index"
            ],
            "arguments": [
                {
                    "prefix": "--xg-name",
                    "valueFrom": "$(inputs.vg.nameroot).xg"
                },
                {
                    "prefix": "--threads",
                    "valueFrom": "$(runtime.cores)"
                },
                "$(inputs.vg.path)"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.vg.nameroot).xg"
                    },
                    "id": "#xg_index_vg.cwl/genome_xg"
                }
            ],
            "id": "#xg_index_vg.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
